@@ -316,3 +316,17 @@ class StreamChatInterface(abc.ABC):
         :return:
         """
         pass
+
+    @abc.abstractmethod
+    async def check_sqs(self, sqs_key=None, sqs_secret=None, sqs_url=None):
+        """
+        Check SQS Push settings
+
+        When no parameters are given, the current SQS app settings are used
+
+        :param sqs_key: AWS access key
+        :param sqs_secret: AWS secret key
+        :param sqs_url: URL to SQS queue
+        :return:
+        """
+        pass
