@@ -49,7 +49,7 @@ class StreamChat(StreamChatInterface):
         headers["Authorization"] = self.auth_token
         headers["stream-auth-type"] = "jwt"
 
-        url = "{}/{}".format(self.base_url, relative_url)
+        url = f"{self.base_url}/{relative_url}"
 
         if method.__name__ in ["post", "put", "patch"]:
             serialized = json.dumps(data)
@@ -97,16 +97,16 @@ class StreamChat(StreamChatInterface):
         return self.update_users_partial([update])
 
     def delete_user(self, user_id, **options):
-        return self.delete("users/{}".format(user_id), options)
+        return self.delete(f"users/{user_id}", options)
 
     def deactivate_user(self, user_id, **options):
-        return self.post("users/{}/deactivate".format(user_id), data=options)
+        return self.post(f"users/{user_id}/deactivate", data=options)
 
     def reactivate_user(self, user_id, **options):
-        return self.post("users/{}/reactivate".format(user_id), data=options)
+        return self.post(f"users/{user_id}/reactivate", data=options)
 
     def export_user(self, user_id, **options):
-        return self.get("users/{}/export".format(user_id), options)
+        return self.get(f"users/{user_id}/export", options)
 
     def ban_user(self, target_id, **options):
         data = {"target_user_id": target_id, **options}
@@ -162,13 +162,13 @@ class StreamChat(StreamChatInterface):
     def update_message(self, message):
         if message.get("id") is None:
             raise ValueError("message must have an id")
-        return self.post("messages/{}".format(message["id"]), data={"message": message})
+        return self.post(f"messages/{message['id']}", data={"message": message})
 
     def delete_message(self, message_id, **options):
-        return self.delete("messages/{}".format(message_id), options)
+        return self.delete(f"messages/{message_id}", options)
 
     def get_message(self, message_id):
-        return self.get("messages/{}".format(message_id))
+        return self.get(f"messages/{message_id}")
 
     def query_users(self, filter_conditions, sort=None, **options):
         params = options.copy()
@@ -191,13 +191,13 @@ class StreamChat(StreamChatInterface):
         return self.post("channeltypes", data=data)
 
     def get_channel_type(self, channel_type):
-        return self.get("channeltypes/{}".format(channel_type))
+        return self.get(f"channeltypes/{channel_type}")
 
     def list_channel_types(self):
         return self.get("channeltypes")
 
     def update_channel_type(self, channel_type, **settings):
-        return self.put("channeltypes/{}".format(channel_type), data=settings)
+        return self.put(f"channeltypes/{channel_type}", data=settings)
 
     def delete_channel_type(self, channel_type):
         """
@@ -206,7 +206,7 @@ class StreamChat(StreamChatInterface):
         :param channel_type: the channel type
         :return:
         """
-        return self.delete("channeltypes/{}".format(channel_type))
+        return self.delete(f"channeltypes/{channel_type}")
 
     def channel(self, channel_type, channel_id=None, data=None):
         """
@@ -226,13 +226,13 @@ class StreamChat(StreamChatInterface):
         return self.post("commands", data=data)
 
     def delete_command(self, name):
-        return self.delete("commands/{}".format(name))
+        return self.delete(f"commands/{name}")
 
     def get_command(self, name):
-        return self.get("commands/{}".format(name))
+        return self.get(f"commands/{name}")
 
     def update_command(self, name, **settings):
-        return self.put("commands/{}".format(name), data=settings)
+        return self.put(f"commands/{name}", data=settings)
 
     def add_device(self, device_id, push_provider, user_id):
         """
@@ -282,7 +282,7 @@ class StreamChat(StreamChatInterface):
             url = "file://" + url
         content = urlopen(Request(url, headers={"User-Agent": "Mozilla/5.0"})).read()
         response = requests.post(
-            "{}/{}".format(self.base_url, uri),
+            f"{self.base_url}/{uri}",
             params=self.get_default_params(),
             data={"user": json.dumps(user)},
             files={"file": (name, content, content_type)},
@@ -314,7 +314,7 @@ class StreamChat(StreamChatInterface):
         :param name: the name of the blocklist
         :return: blocklist dict representation
         """
-        return self.get("blocklists/{}".format(name))
+        return self.get(f"blocklists/{name}")
 
     def update_blocklist(self, name, words):
         """
@@ -324,7 +324,7 @@ class StreamChat(StreamChatInterface):
         :param words: the list of blocked words (replaces the current list)
         :return:
         """
-        return self.put("blocklists/{}".format(name), data={"words": words})
+        return self.put(f"blocklists/{name}", data={"words": words})
 
     def delete_blocklist(self, name):
         """Delete a blocklist by name
@@ -332,4 +332,18 @@ class StreamChat(StreamChatInterface):
         :param: the name of the blocklist
         :return:
         """
-        return self.delete("blocklists/{}".format(name))
+        return self.delete(f"blocklists/{name}")
+
+    def check_sqs(self, sqs_key=None, sqs_secret=None, sqs_url=None):
+        """
+        Check SQS Push settings
+
+        When no parameters are given, the current SQS app settings are used
+
+        :param sqs_key: AWS access key
+        :param sqs_secret: AWS secret key
+        :param sqs_url: URL to SQS queue
+        :return:
+        """
+        data = {"sqs_key": sqs_key, "sqs_secret": sqs_secret, "sqs_url": sqs_url}
+        return self.post("check_sqs", data=data)
